@@ -6,7 +6,7 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib\Net\SFTP;
+use phpseclib3\Net\SFTP;
 
 class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
 {
@@ -25,20 +25,12 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         self::$exampleDataLength = 10000;
     }
 
-    public function testBadHostname()
-    {
-        $this->setExpectedException('PHPUnit_Framework_Error_Notice');
-
-        $sftp = new SFTP('bad host name');
-        $sftp->login('username', 'password');
-    }
-
     public function testConstructor()
     {
         $sftp = new SFTP($this->getEnv('SSH_HOSTNAME'));
 
-        $this->assertTrue(
-            is_object($sftp),
+        $this->assertIsObject(
+            $sftp,
             'Could not construct NET_SFTP object.'
         );
 
@@ -135,7 +127,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
     public function testStatOnDir($sftp)
     {
         $this->assertNotSame(
-            array(),
+            [],
             $sftp->stat('.'),
             'Failed asserting that the cwd has a non-empty stat.'
         );
@@ -165,7 +157,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
 
         $this->assertSame(
             self::$exampleDataLength,
-            $sftp->size('file1.txt'),
+            $sftp->filesize('file1.txt'),
             'Failed asserting that put example data has the expected length'
         );
 
@@ -175,6 +167,23 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
             'Failed asserting that get() returns expected example data.'
         );
 
+        $this->assertTrue(
+            $sftp->put('file1.txt', 'xxx', SFTP::RESUME),
+            'Failed asserting that an upload could be successfully resumed'
+        );
+
+        $this->assertSame(
+            self::$exampleDataLength + 3,
+            $sftp->filesize('file1.txt'),
+            'Failed asserting that put example data has the expected length'
+        );
+
+        $this->assertSame(
+            self::$exampleData . 'xxx',
+            $sftp->get('file1.txt'),
+            'Failed asserting that get() returns expected example data.'
+        );
+
         return $sftp;
     }
 
@@ -185,13 +194,13 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
     {
         self::$buffer = self::$exampleData;
         $this->assertTrue(
-            $sftp->put('file1.txt', array(__CLASS__, 'demoCallback'), $sftp::SOURCE_CALLBACK),
+            $sftp->put('file1.txt', [__CLASS__, 'demoCallback'], $sftp::SOURCE_CALLBACK),
             'Failed asserting that example data could be successfully put().'
         );
 
         $this->assertSame(
             self::$exampleDataLength,
-            $sftp->size('file1.txt'),
+            $sftp->filesize('file1.txt'),
             'Failed asserting that put example data has the expected length'
         );
 
@@ -239,7 +248,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
 
         $this->assertSame(
             1024 * 1024,
-            $sftp->size('file3.txt'),
+            $sftp->filesize('file3.txt'),
             'Failed asserting that truncate()\'d file has the expected length'
         );
 
@@ -333,7 +342,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $sftp->setListOrder('filename', SORT_DESC);
 
         $list = $sftp->nlist();
-        $expected = array('.', '..', 'temp', 'file3.txt', 'file2.txt', 'file1.txt');
+        $expected = ['.', '..', 'temp', 'file3.txt', 'file2.txt', 'file1.txt'];
 
         $this->assertSame(
             $list,
@@ -344,7 +353,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $sftp->setListOrder('filename', SORT_ASC);
 
         $list = $sftp->nlist();
-        $expected = array('.', '..', 'temp', 'file1.txt', 'file2.txt', 'file3.txt');
+        $expected = ['.', '..', 'temp', 'file1.txt', 'file2.txt', 'file3.txt'];
 
         $this->assertSame(
             $list,
@@ -359,7 +368,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $last_size = 0x7FFFFFFF;
         foreach ($files as $file) {
             if ($sftp->is_file($file)) {
-                $cur_size = $sftp->size($file);
+                $cur_size = $sftp->filesize($file);
                 $this->assertLessThanOrEqual(
                     $last_size,
                     $cur_size,
@@ -551,7 +560,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $filename = 'file-large-from-truncate-4112MiB.txt';
         $this->assertTrue($sftp->touch($filename));
         $this->assertTrue($sftp->truncate($filename, $filesize));
-        $this->assertSame($filesize, $sftp->size($filename));
+        $this->assertSame($filesize, $sftp->filesize($filename));
 
         return $sftp;
     }
@@ -611,7 +620,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         );
         $this->assertIsArray(
             $sftp->stat(self::$scratchDir),
-            'Failed asserting that stat on an existant empty directory returns an array'
+            'Failed asserting that stat on an existent empty directory returns an array'
         );
         $this->assertTrue(
             $sftp->delete(self::$scratchDir),
@@ -623,12 +632,6 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
             'Failed asserting that stat on a deleted directory returns false'
         );
 
-        $this->assertFalse(
-            $sftp->delete(self::$scratchDir),
-            'Failed asserting that non-existent directory could not ' .
-            'be deleted using recursive delete().'
-        );
-
         return $sftp;
     }
 
@@ -735,8 +738,6 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         sleep(5);
         $sftp->nlist();
 
-        $this->assertTrue(true);
-
         return $sftp;
     }
 
@@ -762,35 +763,5 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $list_cache_disabled = $sftp->rawlist('.', true);
 
         $this->assertEquals($list_cache_enabled, $list_cache_disabled, 'The files should be the same regardless of stat cache', 0.0, 10, true);
-
-        return $sftp;
-    }
-
-    /**
-     * @depends testRawlistDisabledStatCache
-     */
-    public function testChownChgrp($sftp)
-    {
-        $stat = $sftp->stat(self::$scratchDir);
-        $this->assertTrue($sftp->chown(self::$scratchDir, $stat['uid']));
-        $this->assertTrue($sftp->chgrp(self::$scratchDir, $stat['gid']));
-
-        $sftp->clearStatCache();
-        $stat2 = $sftp->stat(self::$scratchDir);
-        $this->assertSame($stat['uid'], $stat2['uid']);
-        $this->assertSame($stat['gid'], $stat2['gid']);
-
-        return $sftp;
-    }
-
-    /**
-     * @depends testChownChgrp
-     * @group github1934
-     */
-    public function testCallableGetWithLength($sftp)
-    {
-        $sftp->put('test.txt', 'zzzzz');
-        $sftp->get('test.txt', function($data) {}, 0, 1);
-        $this->assertTrue(true);
     }
 }
