@@ -5,63 +5,63 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib\File\ASN1;
+use phpseclib3\File\ASN1;
 
 class Unit_File_ASN1Test extends PhpseclibTestCase
 {
     /**
-     * on older versions of \phpseclib\File\ASN1 this would yield a PHP Warning
+     * on older versions of \phpseclib3\File\ASN1 this would yield a PHP Warning
      * @group github275
      */
     public function testAnyString()
     {
-        $KDC_REP = array(
+        $KDC_REP = [
             'type' => ASN1::TYPE_SEQUENCE,
-            'children' => array(
-                'pvno' => array(
+            'children' => [
+                'pvno' => [
                     'constant' => 0,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY),
-                'msg-type' => array(
+                    'type' => ASN1::TYPE_ANY],
+                'msg-type' => [
                     'constant' => 1,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY),
-                'padata' => array(
+                    'type' => ASN1::TYPE_ANY],
+                'padata' => [
                     'constant' => 2,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY),
-                'crealm' => array(
+                    'type' => ASN1::TYPE_ANY],
+                'crealm' => [
                     'constant' => 3,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY),
-                'cname' => array(
+                    'type' => ASN1::TYPE_ANY],
+                'cname' => [
                     'constant' => 4,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY),
-                'ticket' => array(
+                    'type' => ASN1::TYPE_ANY],
+                'ticket' => [
                     'constant' => 5,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY),
-                'enc-part' => array(
+                    'type' => ASN1::TYPE_ANY],
+                'enc-part' => [
                     'constant' => 6,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY)
-            )
-        );
+                    'type' => ASN1::TYPE_ANY]
+            ]
+        ];
 
-        $AS_REP = array(
+        $AS_REP = [
             'class'    => ASN1::CLASS_APPLICATION,
             'cast'     => 11,
             'optional' => true,
             'explicit' => true
-        ) + $KDC_REP;
+        ] + $KDC_REP;
 
         $str = 'a4IC3jCCAtqgAwIBBaEDAgELoi8wLTAroQMCAROiJAQiMCAwHqADAgEXoRcbFUNSRUFUVUlUWS5ORVR0ZXN0dXNlcqMPGw' .
                '1DUkVBVFVJVFkuTkVUpBUwE6ADAgEBoQwwChsIdGVzdHVzZXKlggFOYYIBSjCCAUagAwIBBaEPGw1DUkVBVFVJVFkuTkVU' .
@@ -75,145 +75,144 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
                '4P3wep6uNMLnLzXJmUaAMaopjE+MOcai/t6T9Vg4pERF5Waqwg5ibAbVGK19HuS4LiKiaY3JsyYBuNkEDwiqM7i1Ekw3V+' .
                '+zoEIxqgXjGgPdrWkzU/H6rnXiqMtiZZqUXwWY0zkCmy';
 
-        $asn1 = new ASN1();
-        $decoded = $asn1->decodeBER(base64_decode($str));
-        $result = $asn1->asn1map($decoded[0], $AS_REP);
+        $decoded = ASN1::decodeBER(base64_decode($str));
+        $result = ASN1::asn1map($decoded[0], $AS_REP);
 
         $this->assertIsArray($result);
     }
 
     /**
-     * on older versions of \phpseclib\File\ASN1 this would produce a null instead of an array
+     * on older versions of \phpseclib3\File\ASN1 this would produce a null instead of an array
      * @group github275
      */
     public function testIncorrectString()
     {
-        $PA_DATA = array(
+        $PA_DATA = [
             'type' => ASN1::TYPE_SEQUENCE,
-            'children' => array(
-                'padata-type' => array(
+            'children' => [
+                'padata-type' => [
                     'constant' => 1,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_INTEGER
-                ),
-                'padata-value' => array(
+                ],
+                'padata-value' => [
                     'constant' => 2,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_OCTET_STRING
-                )
-            )
-        );
+                ]
+            ]
+        ];
 
-        $PrincipalName = array(
+        $PrincipalName = [
             'type' => ASN1::TYPE_SEQUENCE,
-            'children' => array(
-                'name-type' => array(
+            'children' => [
+                'name-type' => [
                     'constant' => 0,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_INTEGER
-                ),
-                'name-string' => array(
+                ],
+                'name-string' => [
                     'constant' => 1,
                     'optional' => true,
                     'explicit' => true,
                     'min' => 0,
                     'max' => -1,
                     'type' => ASN1::TYPE_SEQUENCE,
-                    'children' => array('type' => ASN1::TYPE_IA5_STRING) // should be \phpseclib\File\ASN1::TYPE_GENERAL_STRING
-                )
-            )
-        );
+                    'children' => ['type' => ASN1::TYPE_IA5_STRING] // should be \phpseclib3\File\ASN1::TYPE_GENERAL_STRING
+                ]
+            ]
+        ];
 
-        $Ticket = array(
+        $Ticket = [
             'class'    => ASN1::CLASS_APPLICATION,
             'cast'     => 1,
             'optional' => true,
             'explicit' => true,
             'type' => ASN1::TYPE_SEQUENCE,
-            'children' => array(
-                'tkt-vno' => array(
+            'children' => [
+                'tkt-vno' => [
                     'constant' => 0,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_INTEGER
-                ),
-                'realm' => array(
+                ],
+                'realm' => [
                     'constant' => 1,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_ANY
-                ),
-                'sname' => array(
+                ],
+                'sname' => [
                     'constant' => 2,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_ANY
-                ),
-                'enc-part' => array(
+                ],
+                'enc-part' => [
                     'constant' => 3,
                     'optional' => true,
                     'explicit' => true,
                     'type' => ASN1::TYPE_ANY
-                )
-            )
-        );
+                ]
+            ]
+        ];
 
-        $KDC_REP = array(
+        $KDC_REP = [
             'type' => ASN1::TYPE_SEQUENCE,
-            'children' => array(
-                'pvno' => array(
+            'children' => [
+                'pvno' => [
                     'constant' => 0,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_INTEGER),
-                'msg-type' => array(
+                    'type' => ASN1::TYPE_INTEGER],
+                'msg-type' => [
                      'constant' => 1,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_INTEGER),
-                'padata' => array(
+                    'type' => ASN1::TYPE_INTEGER],
+                'padata' => [
                     'constant' => 2,
                     'optional' => true,
                     'explicit' => true,
                     'min' => 0,
                     'max' => -1,
                     'type' => ASN1::TYPE_SEQUENCE,
-                    'children' => $PA_DATA),
-                'crealm' => array(
+                    'children' => $PA_DATA],
+                'crealm' => [
                     'constant' => 3,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_OCTET_STRING),
-                'cname' => array(
+                    'type' => ASN1::TYPE_OCTET_STRING],
+                'cname' => [
                     'constant' => 4,
                     'optional' => true,
-                    'explicit' => true) + $PrincipalName,
+                    'explicit' => true] + $PrincipalName,
                     //'type' => ASN1::TYPE_ANY),
-                'ticket' => array(
+                'ticket' => [
                     'constant' => 5,
                     'optional' => true,
                     'implicit' => true,
                     'min' => 0,
                     'max' => 1,
                     'type' => ASN1::TYPE_SEQUENCE,
-                    'children' => $Ticket),
-                'enc-part' => array(
+                    'children' => $Ticket],
+                'enc-part' => [
                     'constant' => 6,
                     'optional' => true,
                     'explicit' => true,
-                    'type' => ASN1::TYPE_ANY)
-            )
-        );
+                    'type' => ASN1::TYPE_ANY]
+            ]
+        ];
 
-        $AS_REP = array(
+        $AS_REP = [
             'class'    => ASN1::CLASS_APPLICATION,
             'cast'     => 11,
             'optional' => true,
             'explicit' => true
-        ) + $KDC_REP;
+        ] + $KDC_REP;
 
         $str = 'a4IC3jCCAtqgAwIBBaEDAgELoi8wLTAroQMCAROiJAQiMCAwHqADAgEXoRcbFUNSRUFUVUlUWS5ORVR0ZXN0dXNlcqMPGw' .
                '1DUkVBVFVJVFkuTkVUpBUwE6ADAgEBoQwwChsIdGVzdHVzZXKlggFOYYIBSjCCAUagAwIBBaEPGw1DUkVBVFVJVFkuTkVU' .
@@ -227,9 +226,8 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
                '4P3wep6uNMLnLzXJmUaAMaopjE+MOcai/t6T9Vg4pERF5Waqwg5ibAbVGK19HuS4LiKiaY3JsyYBuNkEDwiqM7i1Ekw3V+' .
                '+zoEIxqgXjGgPdrWkzU/H6rnXiqMtiZZqUXwWY0zkCmy';
 
-        $asn1 = new ASN1();
-        $decoded = $asn1->decodeBER(base64_decode($str));
-        $result = $asn1->asn1map($decoded[0], $AS_REP);
+        $decoded = ASN1::decodeBER(base64_decode($str));
+        $result = ASN1::asn1map($decoded[0], $AS_REP);
 
         $this->assertIsArray($result);
     }
@@ -239,8 +237,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
      */
     public function testIndefiniteLength()
     {
-        $asn1 = new ASN1();
-        $decoded = $asn1->decodeBER(file_get_contents(dirname(__FILE__) . '/ASN1/FE.pdf.p7m'));
+        $decoded = ASN1::decodeBER(file_get_contents(dirname(__FILE__) . '/ASN1/FE.pdf.p7m'));
         $this->assertCount(5, $decoded[0]['content'][1]['content'][0]['content']); // older versions would have returned 3
     }
 
@@ -264,8 +261,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
                'AAOBgQAhrNWuyjSJWsKrUtKyNGadeqvu5nzVfsJcKLt0AMkQH0IT/GmKHiSgAgDp' .
                'ulvKGQSy068Bsn5fFNum21K5mvMSf3yinDtvmX3qUA12IxL/92ZzKbeVCq3Yi7Le' .
                'IOkKcGQRCMha8X2e7GmlpdWC1ycenlbN0nbVeSv3JUMcafC4+Q==';
-        $asn1 = new ASN1();
-        $decoded = $asn1->decodeBER(base64_decode($str));
+        $decoded = ASN1::decodeBER(base64_decode($str));
         $this->assertCount(3, $decoded[0]['content']);
     }
 
@@ -274,8 +270,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
      */
     public function testContextSpecificNonConstructed()
     {
-        $asn1 = new ASN1();
-        $decoded = $asn1->decodeBER(base64_decode('MBaAFJtUo7c00HsI5EPZ4bkICfkOY2Pv'));
+        $decoded = ASN1::decodeBER(base64_decode('MBaAFJtUo7c00HsI5EPZ4bkICfkOY2Pv'));
         $this->assertIsString($decoded[0]['content'][0]['content']);
     }
 
@@ -284,8 +279,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
      */
     public function testEmptyContextTag()
     {
-        $asn1 = new ASN1();
-        $decoded = $asn1->decodeBER("\xa0\x00");
+        $decoded = ASN1::decodeBER("\xa0\x00");
         $this->assertIsArray($decoded);
         $this->assertCount(0, $decoded[0]['content']);
     }
@@ -295,9 +289,20 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
      */
     public function testInfiniteLoop()
     {
-        $asn1 = new ASN1();
         $data = base64_decode('MD6gJQYKKwYBBAGCNxQCA6AXDBVvZmZpY2VAY2VydGRpZ2l0YWwucm+BFW9mZmljZUBjZXJ0ZGlnaXRhbC5ybw==');
-        $asn1->decodeBER($data);
+        ASN1::decodeBER($data);
+    }
+
+    public function testMaps()
+    {
+        $files = scandir('phpseclib/File/ASN1/Maps');
+        foreach ($files as $file) {
+            if ($file == '.' || $file == '..') {
+                continue;
+            }
+
+            constant('phpseclib3\\File\\ASN1\\Maps\\' . basename($file, '.php') . '::MAP');
+        }
     }
 
     public function testApplicationTag()
@@ -323,11 +328,10 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
 
         $data = array('version' => 'v3');
 
-        $asn1 = new ASN1();
-        $str = $asn1->encodeDER($data, $map);
+        $str = ASN1::encodeDER($data, $map);
 
-        $decoded = $asn1->decodeBER($str);
-        $arr = $asn1->asn1map($decoded[0], $map);
+        $decoded = ASN1::decodeBER($str);
+        $arr = ASN1::asn1map($decoded[0], $map);
 
         $this->assertSame($data, $arr);
     }
@@ -338,8 +342,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
     public function testInvalidCertificate()
     {
         $data = 'a' . base64_decode('MD6gJQYKKwYBBAGCNxQCA6AXDBVvZmZpY2VAY2VydGRpZ2l0YWwucm+BFW9mZmljZUBjZXJ0ZGlnaXRhbC5ybw==');
-        $asn1 = new ASN1();
-        $asn1->decodeBER($data);
+        ASN1::decodeBER($data);
     }
 
     /**
@@ -350,18 +353,16 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
         // from the example in 8.19.5 in the following:
         // https://www.itu.int/ITU-T/studygroups/com17/languages/X.690-0207.pdf#page=22
         $orig = pack('H*', '813403');
-        $asn1 = new ASN1();
-        $new = $asn1->_decodeOID($orig);
+        $new = ASN1::decodeOID($orig);
         $this->assertSame('2.100.3', $new);
-        $this->assertSame($orig, $asn1->_encodeOID($new));
+        $this->assertSame($orig, ASN1::encodeOID($new));
 
         // UUID OID from the following:
         // https://healthcaresecprivacy.blogspot.com/2011/02/creating-and-using-unique-id-uuid-oid.html
         $orig = '2.25.329800735698586629295641978511506172918';
-        $asn1 = new ASN1();
-        $new = $asn1->_encodeOID($orig);
+        $new = ASN1::encodeOID($orig);
         $this->assertSame(pack('H*', '6983f09da7ebcfdee0c7a1a7b2c0948cc8f9d776'), $new);
-        $this->assertSame($orig, $asn1->_decodeOID($new));
+        $this->assertSame($orig, ASN1::decodeOID($new));
     }
 
     /**
@@ -385,80 +386,10 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
             )
         );
 
-        $asn1 = new ASN1();
         $a = pack('H*', '3026a011180f32303137303432313039303535305aa111180f32303138303432313230353935395a');
-        $a = $asn1->decodeBER($a);
-        $a = $asn1->asn1map($a[0], $map);
+        $a = ASN1::decodeBER($a);
+        $a = ASN1::asn1map($a[0], $map);
 
         $this->assertIsArray($a);
     }
-
-    public function testNullGarbage()
-    {
-        $asn1 = new ASN1();
-
-        $em = pack('H*', '3080305c0609608648016503040201054f8888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888804207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-
-        $em = pack('H*', '3080307f0609608648016503040201057288888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888804207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca90000');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-    }
-
-    public function testOIDGarbage()
-    {
-        $asn1 = new ASN1();
-
-        $em = pack('H*', '3080305c065860864801650304020188888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888050004207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-
-        $em = pack('H*', '3080307f067d608648016503040201888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888888804207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-    }
-
-    public function testConstructedMismatch()
-    {
-        $asn1 = new ASN1();
-
-        $em = pack('H*', '1031300d0609608648016503040201050004207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-
-        $em = pack('H*', '3031100d0609608648016503040201050004207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-
-        $em = pack('H*', '3031300d2609608648016503040201050004207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-
-        $em = pack('H*', '3031300d06096086480165030402012d0004207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-    }
-
-    public function testBadTagSecondOctet()
-    {
-        $asn1 = new ASN1();
-
-        $em = pack('H*', '3033300f1f808080060960864801650304020104207509e5bda0c762d2bac7f90d758b5b2263fa01ccbc542ab5e3df163be08e6ca9');
-        $decoded = $asn1->decodeBER($em);
-        $this->assertFalse($decoded[0]);
-    }
-
-    public function testLongOID()
-    {
-        $cert = file_get_contents(dirname(__FILE__) . '/ASN1/mal-cert-02.der');
-
-        $asn1 = new ASN1();
-        //$this->setExpectedException('PHPUnit_Framework_Error_Notice');
-        $decoded = $asn1->decodeBER($cert);
-        $this->assertFalse($decoded[0]);
-
-        //$x509 = new X509();
-        //$x509->loadX509($cert);
-    }
 }
